@@ -1,8 +1,9 @@
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns, url
 
 from . import views
 
-urlpatterns = patterns('',
+urlpatterns = patterns(
+    '',
     url(r'^activate/complete/$', views.activation_complete,
         name='registration_activation_complete'),
 
